#
# spec file for package md_monitor
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           md_monitor
BuildRequires:  libaio-devel
BuildRequires:  libudev-devel
Requires:       mdadm
Url:            http://github.com/hreinecke/md_monitor
Summary:        MD device monitor
License:        GPL-2.0+
Group:          Development/Tools/Other
Version:        6.6
Release:        3.3.1
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Source0:        %{name}-%{version}.tar.xz

%description
The md_monitor daemon monitors the component devices of each MD array
for I/O issues. It will update the monitored MD arrays on each status
change, setting devices to 'faulty' or re-integrate working devices.

Authors:
--------
    Hannes Reinecke <hare@suse.de>

%prep
%setup -q -n %{name}-%{version}

%post
%{fillup_only -n md_monitor}

%build
make OPTFLAGS="$RPM_OPT_FLAGS"

%install
make DESTDIR=$RPM_BUILD_ROOT install

%if ! %{defined _fillupdir}
%define _fillupdir /var/adm/fillup-templates
%endif
if [ "%{_fillupdir}" != /var/adm/fillup-templates \
                     -a -d $RPM_BUILD_ROOT/var/adm/fillup-templates ]; then
   install -d -m 755 $RPM_BUILD_ROOT%{_fillupdir}
   mv -f -t $RPM_BUILD_ROOT%{_fillupdir} \
      $RPM_BUILD_ROOT/var/adm/fillup-templates/sysconfig.md_monitor
   rm -rf $RPM_BUILD_ROOT/var/adm
fi

%clean 
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root)
/sbin/md_monitor
/sbin/setdasd
%{_mandir}/man8/md_monitor.8*
%{_mandir}/man8/setdasd.8*
/usr/share/misc/md_notify_device.sh
/usr/lib/systemd/system/md_monitor.service
%{_fillupdir}/sysconfig.md_monitor
%doc README.md

%changelog
* Tue Feb 25 2020 colyli@suse.com
- Fixes for md_monitor.spec,
  * remove 'V' and 'v' when reference md_monitor version string:
    Source0: from %%{name}-V%%{version} to %%{name}-%%{version}
    %%setup: from %%{name}-v%%{version} %%{name}-%%{version}
  * add md_monitor.service into %%files because md_monitor has
    it since v6.5.
  * force %%_fillupdir to be /var/adm/fillup-templates/ before
    upstream changes to new location /usr/share/fillup-templates/
  * add %%post section.
* Mon Feb 24 2020 colyli@suse.com
- Update to version 6.6:
  * md_monitor: use pselect() instead of select() (bsc#1095141)
  * md_monitor: permanently store 'md_side' for each device
    (bsc#1116560)
  * md_monitor: skip devices with valid md_slot in reset_mirror()
    (bsc#1116560)
  * md_monitor: fix potential memleak in discover_md_components()
    (bsc#1157754)
- The above update also has the following changes included in
  version 6.5 :
  * md_monitor: check for device and alias name in lookup_md_new()
    (bsc#1125281)
  * md_monitor: send SIGHUP to thread before cancellation
    (bsc#1125281)
  * md_monitor: Do not set 'REMOVED' state if ioctl fails
    (bsc#1125281)
  * md_monitor: close race in setting dev->thread (bsc#1125281)
  * md_monitor: add pthread synchronisation points (bsc#1125281)
  * md_monitor: fixup md structure initialisation (bsc#1125281)
  * md_monitor: Fix possible corruption of pending_list (bsc#1149316)
  * md_monitor: Fix locking of md_dev->status_lock in
    mdadm_exec_thread() (bsc#1149316)
  * md_monitor: display_md_status: don't omit trailing dots
  * md_monitor: use correct blocksize in io_prep_pread() (bsc#1139268)
  * md_monitor: add newly (re-)discovered devices to the device list
    (bsc#1136542)
  * md_monitor: skip non-RAID10 arrays (bsc#1123046)
  * Add systemd service file for systemd with increased TaskMax
    and LimitNOFILE (bsc#1104770)
  * Fix crash on MonitorStatus (bsc#1096363, bsc#1081286)
  * Ignore NewArray message if does not exists yet (bsc#1091619)
  * md_monitor: fixup crash in display_md_status (bsc#1081286)
- The above update includes patches for (bsc#1125281) and (bsc#1123046),
  they are required by (bsc#1157098)
* Thu Jan 25 2018 hare@suse.de
- Update to version 6.4:
  * Clear message buffer before sending reply (bsc#1068175)
  * Ignore inactive arrays (bsc#1068175)
  * Store alias in struct md_dev to avoid lookup errors (bsc#1068175)
  * Move testcases to use MD alias name
  * Autodetect chpids for testcase5
  * Correctly enumerate raid disks during reshaping
  * Add missing timeout value for testcase10
* Wed Apr 12 2017 hare@suse.de
- Update to version 6.3:
  * Work around dirty bitmap issue (bsc#951211)
  * Work around changed output in mdadm (bsc#954769)
  * Cleanup monitor_testcase_functions.sh
  * Ignore EBUSY returns from mdadm --fail (bsc#955975)
  * monitor_testcase_functions: extend wait_for_monitor timeout
  * Further updates for zFCP tests
  * Handle empty device-mapper UUIDs
  * Compare the device name length fo the testing devices (bsc#959718)
  * monitor_testcase_functions: Add 'mdadm --wait-clean' (bsc#951211)
  * Fixup return value from reset_md() (bsc#1013061)
  * Fixup testcases for older installations
  * Fixup uninitialized return value (bsc#1033734)
- Use osc _service to retrieve package tarball
* Thu Nov  5 2015 hare@suse.de
- Update to version 6.0:
  * Include zFCP support (FATE#319070)
  * Update scripts for zFCP
- Update to version 6.1:
  * Set 'timeout' DASD attribute correctly on newer kernels
- Update to version 6.2:
  * Include scripts to setup root on MD
  * Set 'failfast' attribute correctly on newer kernels
  * Call 'mdadm --wait' when shutdown array (bsc#951211)
  * Include workaround for bsc#953510
  * Open device nodes read-only (bsc#937340)
  * Use curl instead of wget
  * Fix I/O timeout handling to work with newer kernel
  * Include workaround for bug#937340
* Thu Sep 17 2015 hare@suse.de
- Set 'timeout' DASD attribute for recent kernels (bsc#943270)
- Fixup typo testcase_monitor_functions.sh
* Fri Aug 28 2015 hare@suse.de
- Update to version 5.1
  * Fixup locking in dasd_monitor_thread (bnc#839559)
  * Fixup uninitialized variable
  * Close cli socket on error
  * Terminate string when reading from sysfs
  * Use MD in name in lookup_md_alias (bnc#876830)
- Update to version 5.2
  * Fixes from coverity
- Update to version 5.3
  * Skip devices not in state 'online' (bnc#920563)
  * Open MD device nodes read-only
  * Skip uninitialized devices during scanning
  * Fixup testcases for SLE12
- Update to version 6.0 to add zFCP support (FATE#319070)
  * Split off DASD support routines in separate file
  * Rework MD detection logic
  * Support multipath devices
  * Update some testcases for zFCP
* Fri Jan 24 2014 hare@suse.de
- Branched off from the mdadm package, version 5.0 (FATE#316685)
